function JHCFRates(lastdayused)
% Calculate case fatality rates for JH data at lastdayused
% as functions of k of the k-day rule and the backlog used
kstep=1 % step for k
backstep=1% step for backlog 
kmin=7 % minimal k used,
kmax=21 % maximal k used
backmax=50 % maximal backlog used 
% Minimal backlog will be 2*kmin,
% but we calculate only when backlog >= 2*k 
%
% countrylist={ 'Germany' 'Brazil' 'Russia' 'Italy' 'Spain' ...
%         'Sweden' 'Austria' 'France' 'UK', 'US',...
%         'Denmark','Switzerland'};
countrylist=GetCoronaCountryList;
%
for i=1:length(countrylist)  % loop over countries
    country=char(countrylist(i))
    %     %
    if i~=1
        break
    end
    %   the final two parameters are not used because we do not use ER
    [tC, C, tI, I, tR, R, tD, D, tER, ER]=getCIRD(country, lastdayused, 14, 28);
    % but now we smoothe because we want to estimate
    C=mylogsmoother(C);
    C=mylogsmoother(C);
    D=mylogsmoother(D);
    D=mylogsmoother(D);
    R=mylogsmoother(R);
    R=mylogsmoother(R);
    len=length(C)
    % get differences
    dD=zeros(len,1);
    dD(2:end)=D(2:end)-D(1:end-1);
    dC=zeros(len,1);
    dC(2:end)=C(2:end)-C(1:end-1);
    % start for the loop over (k,backlog) pairs
    [dx, dy]=meshgrid(kmin:kstep:kmax,2*kmin:backstep:backmax);
    ddx=[dx(:) dy(:)];
    cFR=zeros(length(ddx(:,1)),1); % for case fatality rates
    for j=1:length(ddx(:,1)) % loop over pairs
        kdays=ddx(j,1); % the k we use in the loop
        backlog=ddx(j,2); % the backlog 
        if backlog<kdays*2
            continue
        end
        % now do the estimation
        pR=estimateRecovered(C, D, kdays, len-backlog+1, len);
        pD=pR(2:kdays+1);
        q=p2q(pD);
        % cFR(k)=sum(pD);
        cFR(j)=1-pR(1);
        sum=zeros(backlog,1);
        for i=1:kdays
            sum=sum+q(i)*dC(len-backlog+1-i:len-i);   
        end
        % sum=(sum-dD(len-backlog+1:len))./max(1,dD(len-backlog+1:len));
        sum=sum-dD(len-backlog+1:len); % )./max(1,dD(len-backlog+1:len));
        % sum=sum./max(1,abs(dD(len-backlog+1:len))); % )./max(1,dD(len-backlog+1:len));
        % err(j)=max(abs(sum)); % norm(sum(:),2)/sqrt(len-backlog+1);  % relative RMSQ
        err(j)=norm(sum(:),2)/sqrt(backlog);  % relative RMSQ
    end 
    figure
    surf(dx, dy, reshape(cFR,size(dx)))
    % title(sprintf('Case death rates for %s on day %d',country, lastdayused))
    %     xlabel('Days till death or Recovery')
    %     ylabel('Number of backlog days used')
    h=gca;
    set(h,'FontSize',15)
    
    figure
    surf(dx, dy, reshape(err,size(dx)))
    h=gca;
    set(h,'FontSize',15)
    
    % title(sprintf('RMSQ error for %s on day %d',country, lastdayused))
    disp(sprintf('Plots are for %s on day %d',country, lastdayused))
    disp('Hit Enter to continue')
    pause
end

function q=p2q(p)
% convert p to q
q=zeros(size(p));
q(1)=1-p(1);
for k=2:length(p)
    q(k)=q(k-1)*(1-p(k));
end
% now the q are the products of the 1-p_j
% then put in p(k) backwards
for k=length(p):-1:2
    q(k)=q(k-1)*p(k);
end
q(1)=p(1);
