function SIR01(color)
% standard SIR model using ode23 ODE solver
% Notations like in the paper
global gamma
global R0
global N
gamma=1;  % fixed gamma
R0low=0.5
R0step=0.5
R0max=5
N=80e6;  % population of Germany
R=0;     % no recovered at startup
% first I(0)=N/2
figure
for R0=R0low:R0step:R0max % loop over R0
    I=N/2;   % MANY Infectious at startup
    S=N-I-R; 
    % starting values:
    y0=[S; I; R];
    [T,Y]=ode23(@SIR,[0 7],y0);
    if color=='black'
        plot(T,Y(:,2)/N,'k',T,Y(:,3)/N,'k:')
    else
        plot(T,Y(:,2)/N,'k',T,Y(:,3)/N,'r')
    end
    hold on
end
h=gca;
set(h,'FontSize',20)
% legend('i','r',4)
% now I(0)=N*0.999
figure
for R0=R0low:R0step:R0max % loop over R0
    S=N*0.999;
    I=N-R-S;
    y0=[S; I; R];
    [T,Y]=ode23(@SIR,[0 17],y0);
    if color=='black'
        plot(T,Y(:,2)/N,'k-',T,Y(:,1)/N,'k-.',T,Y(:,3)/N,'k:')
    else
        plot(T,Y(:,2)/N,'k',T,Y(:,1)/N,'b',T,Y(:,3)/N,'r')
    end
    hold on
end
h=gca;
set(h,'FontSize',20)


function dydt=SIR(t,y)
% the plain SIR ODE subroutine, standard model
global gamma
global R0
global N
S=y(1);
I=y(2);
R=y(3);
dS=-R0*(S/N)*I;
dI=R0*(S/N)*I-gamma*I;
dR=gamma*I;
dydt=[dS; dI; dR];

