function [S, M, H, C, I, R, D, tmod, Smod, Mmod, Hmod, Cmod, Imod, Rmod, Dmod, HCmod, fixR]=...
    myEstimator(country, k, kbacklog, modelbackstart, gIF, backlog, timespan, lastdayused, H0fact, startC)
% 
% this is the full model estimator that does all the steps
%
% Input:
% 
% country: string as from getGoronaCountryList.m, used in GetCoronaData.m
% k : parameter for the k-day rule, deaths and recoverise decided on day
%     k+1 after registration
% modelbackstart : number of days the model goes back behind the latest
%                  possible day, set = 0 for latest prediction
% gIF :            Infection fatality rate from the literature
% gIR :            Infection recovery rate, from the literature
%                  or by estimation
% backlog :        if constants are estimated from time series, use the 
%                  latest backlog+1 values
% timespan :       the number of days for prediction. The model runs up to
%                  day latest-modelstart+timespan
%
% n0=datenum('22-jan-2020');
timespan=timespan+modelbackstart; % the absolute timespan used later
% fetch raw Johns Hopkins data
[tC, C, tI, I, tR, R, tD, D, tER, ER]=getCIRD(country, lastdayused, k, kbacklog);
% 
% 
% [C, R, D]=GetCoronaData(country);
% C=C(1:lastdayused);
% R=R(1:lastdayused);
% D=D(1:lastdayused);
% % get parameters
pars=getCoronaParameters(country);   
% this gives the actual day until values are available:
len=length(C)
% but we eventually go back for testing the model
modelstart=len-modelbackstart;
% for using smoothed data, we prepare thm already here,
% but we keep the original data
CS=mylogsmoother(C);
CS=mylogsmoother(CS);+1
DS=mylogsmoother(D);
DS=mylogsmoother(DS);
RS=mylogsmoother(R);
RS=mylogsmoother(RS);
% get population size
N=pars(2);
% check if we need to estimate R values
if pars(3)==1 
    % use the standard setting dependent on k
    % and use the data only up to modelstart, but smoothed
    pR=estimateRecovered(CS, DS, k, modelstart-2*k+1, modelstart);
    % get the new R out of this
    R=pR(k+2:end);
    RS=R; % the R estimation is already based on smoothed data
end
% 
% now the Johns Hopkins data are ready, we estimate constants
% but for estimation, we use smoothed data
%
% [bCRD, gammaCRD, r0est, gCRts, gCDts]=getEstimatesFromJohnsHopkins(CS, RS, DS);
[gCRts, gCDts]=getDRRatesFromJohnsHopkins(CS, RS, DS);
% and estimate constants out of time series, only up to modelstart
gCR=backestimate(gCRts(1:modelstart), backlog)
gCD=backestimate(gCDts(1:modelstart), backlog)
% 
% now estimate the case fatality
% This implies another call to estimateRecovered, on smoothed data
gCF=estimate_gCF(CS, DS, k, modelstart-2*k+1, modelstart)  
% get estimated instantaneous infection recovery rate, as in paper
% Replace this as soon as something better is on the market
gIR=(1-gIF)*gCR/(1-gCF)
detR=gIF/gCF
% We need a starting value for H,% and use the 
% underestimation rate of the Removed
tstart=k+min(find(C>=startC));
tstart=min(tstart, lastdayused);
C0=C(tstart)
Ck=C(tstart-k)
H0=H0fact*Ck*gCF/gIF
% prepare generation of missing S, M, H values
gCFgIF=gCF/gIF;
% This uses the original C, not smoothed:
SMH=calibrateSMH(C, N, gCFgIF, gIR, H0, tstart);
S=SMH(:,1);
M=SMH(:,2);
H=SMH(:,3);
% then get gamma beta b timeseries, not smoothed as well
[bet, gam, b]=getbetagammafromSMHCN(S, M, H, C, N);
% and extract the constants using the standard backlog
fixbet=backestimate(bet(1:modelstart), backlog)
fixgam=backestimate(gam(1:modelstart), backlog)       
fixR=fixbet/fixgam
% 
% now prepare the full model run, forget history
%
I=C-R-D;
SMHCIRDstart=zeros(7,1);
SMHCIRDstart(1,1)=S(modelstart);
SMHCIRDstart(2,1)=M(modelstart);
SMHCIRDstart(3,1)=H(modelstart);
SMHCIRDstart(4,1)=C(modelstart);
SMHCIRDstart(5,1)=I(modelstart);
SMHCIRDstart(6,1)=R(modelstart);
SMHCIRDstart(7,1)=D(modelstart);
% and run it
SMHCIRD=runSMHCIRD(SMHCIRDstart, gIF, gCR, gCD, gCF, N, fixbet, fixgam, timespan);
% the times for plotting the prediction
tmod=(modelstart:modelstart+timespan-1)';
% extract results for notational convenience
Smod=SMHCIRD(:,1);
Mmod=SMHCIRD(:,2);
Hmod=SMHCIRD(:,3);
Cmod=SMHCIRD(:,4);
Imod=SMHCIRD(:,5);
Rmod=SMHCIRD(:,6);
Dmod=SMHCIRD(:,7);
HCmod=Cmod+Hmod;


